==> openGion6.7.6.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/WKGE54_XINS.sql <==
/****************************************************************************/
/* WKGE54_XIN ( WKGE54_XIN )                                                */
/*                                                                          */
/* Created : 2017/01/05 15:19:19                                            */
/****************************************************************************/

CREATE TABLE WKGE54_XIN (
   GESYSTEM_ID      varchar (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID           */
 , GEYKNO           INTEGER             DEFAULT 0   NOT NULL            /*  20 要求NO           */
 , GESHEETNO        INTEGER             DEFAULT 0   NOT NULL            /*  30 ｼｰﾄ番号          */
 , GEEDNO           INTEGER             DEFAULT 0   NOT NULL            /*  40 枝番             */
 , SYSTEM_ID        varchar (  10 )                                     /*  50 ｼｽﾃﾑID           */
 , LISTID           varchar (  10 )                                     /*  60 帳票ID           */
 , LISTNAME         varchar ( 100 )                                     /*  70 帳票名称         */
 , MODELDIR         varchar ( 100 )                                     /*  80 雛型ﾌｧｲﾙDIR      */
 , MODELFILE        varchar (  20 )                                     /*  90 雛型ﾌｧｲﾙ名       */
 , FGCUT            varchar (   1 )                                     /* 100 ﾍﾟｰｼﾞｴﾝﾄﾞｶｯﾄﾌﾗｸﾞ */
 , FGLOCAL          varchar (   1 )     DEFAULT 0   NOT NULL            /* 110 ﾛｰｶﾙﾘｿｰｽ         */
 , FGDIRECT         varchar (   1 )     DEFAULT 0   NOT NULL            /* 120 ﾀﾞｲﾚｸﾄ           */
 , COMMENTS         varchar ( 500 )                                     /* 130 ｺﾒﾝﾄ             */
 , RELEASE_NOTES    varchar ( 120 )                                     /* 140 ﾘﾘｰｽﾉｰﾄ          */
 , RDC_CODE         varchar (  20 )                                     /* 150 設変番号         */
);

==> openGion7.2.8.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/WKGE54_XINS.sql <==
/****************************************************************************/
/* WKGE54_XIN ( WKGE54_XIN )                                                */
/*                                                                          */
/* Created : 2018/09/28 16:03:40                                            */
/****************************************************************************/

CREATE TABLE WKGE54_XIN (
   GESYSTEM_ID      varchar (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID           */
 , GEYKNO           INTEGER             DEFAULT 0   NOT NULL            /*  20 要求NO           */
 , GESHEETNO        INTEGER             DEFAULT 0   NOT NULL            /*  30 ｼｰﾄ番号          */
 , GEEDNO           INTEGER             DEFAULT 0   NOT NULL            /*  40 枝番             */
 , SYSTEM_ID        varchar (  10 )                                     /*  50 ｼｽﾃﾑID           */
 , LISTID           varchar (  10 )                                     /*  60 帳票ID           */
 , LISTNAME         varchar ( 100 )                                     /*  70 帳票名称         */
 , MODELDIR         varchar ( 100 )                                     /*  80 雛型ﾌｧｲﾙDIR      */
 , MODELFILE        varchar (  20 )                                     /*  90 雛型ﾌｧｲﾙ名       */
 , FGCUT            varchar (   1 )                                     /* 100 ﾍﾟｰｼﾞｴﾝﾄﾞｶｯﾄﾌﾗｸﾞ */
 , FGLOCAL          varchar (   1 )     DEFAULT '0' NOT NULL            /* 110 ﾛｰｶﾙﾘｿｰｽ         */
 , FGDIRECT         varchar (   1 )     DEFAULT '0' NOT NULL            /* 120 ﾀﾞｲﾚｸﾄ           */
 , COMMENTS         varchar ( 500 )                                     /* 130 ｺﾒﾝﾄ             */
 , RELEASE_NOTES    varchar ( 120 )                                     /* 140 ﾘﾘｰｽﾉｰﾄ          */
 , RDC_CODE         varchar (  20 )                                     /* 150 設変番号         */
);
